#   File Name:  bkup_compress_remove.sh
#
#   Purpose: Compresses a set of files to a given directory 
#            then removes the source files
#             
#   Assumption: The 2nd parameter is a file that contains a single-column 
#                  list of files to be compressed
#
#   Parameters:  
#       $1 SRC_FILE_LST  -  constains a single-column list of files
#       $2 OUTPUT_DIR    -  directory where the compressed files will be saved 
#       $3 HOST_STR      -   Database Name
#       $4 LAST_ARCHIVE_FILE_NUMBER_LST - File contains archive log number
#   Modifications:
#      11/20/2000   Ajay Jain Created 
# 


ERRMSG="`basename $0`: syntax error SRC_FILE_LST OUTPUT_DIR HOST_STR LAST_ARCHIVE_FILE_NUMBER_LST "

if [ "$1" ]; then SRC_FILE_LST=$1; else echo $ERRMSG >&2; exit 1; fi
if [ "$2" ]; then OUTPUT_DIR=$2 ;  else echo $ERRMSG >&2; exit 1; fi
if [ "$3" ]; then HOST_STR=$3 ;    else echo $ERRMSG >&2; exit 1; fi
if [ "$4" ]; then LAST_ARCHIVE_FILE_NUMBER_LST=$4 ;    else echo $ERRMSG >&2; exit 1; fi


RCP_ID=oracle
RCP_SERVER=orafindras

LAST_ARCHIVE_FILE_NUMBER_LST=/orabackup/$HOST_STR/temp/last_archive_file_number.lst
LAST_NUMBER_FROM_DB=`grep last_archive_file_number $LAST_ARCHIVE_FILE_NUMBER_LST |cut -f2 -d=`

cat $SRC_FILE_LST | while read LST1
  do
     CURR_FILE=`basename $LST1`
     LAST_NUMBER_FROM_DIR=`echo $CURR_FILE | cut  -f2 -d_| cut  -f1 -d.`
     if [ $LAST_NUMBER_FROM_DIR -gt $LAST_NUMBER_FROM_DB ]
        then echo " More archive files were generated after start of this process, skipping them "
        exit 0
     fi 
     STARTTIME=`date +%m%d%y.%H:%M:%S`    
     echo "\nCompressing $LST1 TO $OUTPUT_DIR/$CURR_FILE.Z ..." 
     compress < $LST1 > "$OUTPUT_DIR"/"$CURR_FILE".Z 
     STATUS=$?
        if [ $STATUS -ne 0 ]
          then
             echo " \ncompressing of the file $CURR_FILE, failed, could be no space left on disk "
             echo " exiting with status = $STATUS "
             exit 1
          else 
            echo " Successfully Compressed the file, now removing the archive File $LST1 "
            rm $LST1
        fi 
     ENDTIME=`date +%m%d%y.%H:%M:%S`
     COMPRESSED_SZ=`ls -1s "$OUTPUT_DIR"/"$CURR_FILE".Z | awk -F' ' '{print $1}'`
     FILE_SZ=`ls -1s $LST1 | awk -F' ' '{print $1}'`
     echo "File Sz       (KB): $FILE_SZ"  
     echo "Compressed Sz (KB): $COMPRESSED_SZ" 
     echo "Start Time        : " $STARTTIME 
     echo "End   Time        : " $ENDTIME 

  done


