
#   File Name:  archlogs_compress_remove_main.sh 
#
#   Purpose: Compress and remove archive logs of a given instance 
#              
#   Assumptions:
#        1) Instance is in ARCHIVELOG mode
#        2) log_archive_dest only contains the instance's archive logs         
#
#   Parameters:  $1   HOST_STR
#                $2   Backup Directory (optional) 
#

ERRMSG="`basename $0`: syntax error: `basename $0` HOSR_STR BKUP_ARCHLOG_DIR(optional)  "

if [ "$1" ]; then HOST_STR=$1; else echo "$ERRMSG " ; exit 1; fi
if [ "$2" ]; then BKUP_ARCHLOG_DIR=$2; else BKUP_ARCHLOG_DIR=/orabackup/$HOST_STR/arch_save ; fi            

BKUP_SCR=/orabackup/scripts
BKUP_STARTTIME=`date +%m%d%y.%H:%M:%S`
BKUP_TEMP_DIR=/orabackup/$HOST_STR/temp
BKUP_LOG=$BKUP_TEMP_DIR/move_arch.$BKUP_STARTTIME.log
ARCHLOG_LST=$BKUP_TEMP_DIR/archlog_list.$BKUP_STARTTIME.lst
LAST_ARCHIVE_NUMBER_FILE=$BKUP_TEMP_DIR/last_archive_number_file.lst
INST_STAT=$BKUP_TEMP_DIR/instance_status.log

# *** Check if $HOST_STR.env file exists & Then executes the ENV File to set ORACLE Parameters
   ORAENV=/export/home/oracle/$HOST_STR.env
   if [ -r $ORAENV ]; then echo "ENV file exists : $ORAENV"
     else  echo "Missing env file : $ORAENV , needed to set Oracle ENV " >>  $BKUP_LOG
     exit 1
   fi

   . $ORAENV

# *** Check if Temp Dir exists or not 
if [ ! -w $BKUP_TEMP_DIR ]; then mkdir $BKUP_TEMP_DIR; else echo "Temp DIR = $BKUP_TEMP_DIR "; fi

# *** Check if instance is up,
   echo "\nChecking if instance is up ..."
   INSTANCE_STATUS=`$BKUP_SCR/check_instance_up.sh $HOST_STR > $INST_STAT`
     if [ "$INSTANCE_STATUS" = "1" ]; then
        echo "     Instance is not up.   Quitting backup & removal of Archive logs for $HOST_STR...."
        echo "     Status: $INSTANCE_STATUS"
        exit 1
    else
        echo "     Status : INSTANCE  is up, continueing with backup & removal of Archive logs for $HOST_STR...."
     fi

# *** Check if instance is in ARCHIVE LOG mode & get ARCHIVE LOG Destination
   echo "\nChecking if instance is in ARCHIVE LOG mode ..."
   $BKUP_SCR/check_archivelog_mode.sh $BKUP_TEMP_DIR/archive_check.log
   status=$?
   if [ ! $status -eq 0 ]; then echo " System is not in ARCHIVELOG mode"; exit 1; fi
     
   cat  $BKUP_TEMP_DIR/archive_check.log

echo "Moving archive logs of $HOST_STR... :$BKUP_STARTTIME" > $BKUP_LOG

# *** Remove old file from temp & compressed Archived dir
#find $BKUP_TEMP_DIR/*.log   -mtime +2 -exec rm -f {} \;
#find $BKUP_TEMP_DIR/*.lst   -mtime +2 -exec rm -f {} \;
#find $BKUP_ARCHLOG_DIR/*.Z  -mtime +2 -exec rm -f {} \;

# *** Get source DIR name of archive logs 
   echo "\nGetting archive log destination where logs are being generated... " >> $BKUP_LOG
   ARCHLOG_DIR=`$BKUP_SCR/get_archlog_dest.sh $HOST_STR`
   echo " Source archive log Dir = $ARCHLOG_DIR"

# *** Peform log switch & Get last Archive number 
    arch_hot_checkpoint.sh  $LAST_ARCHIVE_NUMBER_FILE


# *** Prepare list of all file currently in the Source Archive dir  
   echo "\nListing contents of $ARCHLOG_DiR ..." >> $BKUP_LOG
--->>>>>>>>>>>>>>>>>>   ls -1rt $ARCHLOG_DIR 
   #ls -1rt $ARCHLOG_DIR | awk '{printf "'$ARCHLOG_DIR'/" $1 "\n"}'  > $ARCHLOG_LST
   echo "Status : " $? >> $BKUP_LOG

# *** Launch Compress & Remove of Archive files 
   $BKUP_SCR/arch_bkup_compress_remove.sh  $ARCHLOG_LST $BKUP_ARCHLOG_DIR $LAST_ARCHIVE_NUMBER_FILE >> $BKUP_LOG
   status=$?
   if [ ! $status -eq 0 ]; then echo " Problem with compressing files "; exit 1; fi

# *** send the archive files to DR server
#   $BKUP_SCR/arch_compress_rcp_2_DR.sh  $ARCHLOG_LST $BKUP_ARCHLOG_DIR $LAST_ARCHIVE_NUMBER_FILE>> $BKUP_LOG

# *** Report Backup Start/End Time
echo "\nMoving of archivelogs of $HOST_STR ended." >> $BKUP_LOG
echo "Start time:  $BKUP_STARTTIME" >> $BKUP_LOG
echo "End   time:  `date +%m%d%y.%H:%M:%S`" >> $BKUP_LOG 



