#   File Name:  backupdb.sh
#   Purpose  :  Performs a backup of a given instance
#   Parameters:  
#                $1  System Password
#                $2  Oracle SID  (must be the same as host string)
#                $3  Backup mode <cold|exp>
#                $4  Number of parallel processes (for cold only,default=3,max=9) 
#
#   History of changes:
#   Created by  :  Ajay Jain  01/15/03
#   Modified by :  


ERRMSG="`basename $0`: syntax error: `basename $0` system_password host_string <cold|exp|hot> <# of parallel jobs>"

if [ "$1" ]; then HOST_STR=$1;     else echo $ERRMSG >&2; exit 1; fi
if [ "$2" ]; then BKUP_MODE=$2;    else echo $ERRMSG >&2; exit 1; fi                                 
if [ "$3" ]; then NUM_OF_PROCS=$3; else NUM_OF_PROCS=9; fi


# *** Set variables needed for running backup scripts 
BIN_DIR=/usr/bin
BKUP_STARTTIME=`date +%m-%d-%Y__%H:%M:%S`
BKUP_DIR=/orabackup/$HOST_STR/$BKUP_MODE
BKUP_ARCH_DIR=/orabackup/$HOST_STR/arch
BKUP_TEMP_DIR=/orabackup/$HOST_STR/temp
BKUP_SCR_DIR=/orabackup/scripts
BKUP_SCR=$BKUP_SCR_DIR/"$BKUP_MODE"_bkup.sh
BKUP_LOG=$BKUP_DIR/backup.$BKUP_STARTTIME   ### Main Backup LOG file 
BKUP_ERR=$BKUP_DIR/backup.$BKUP_STARTTIME.err
BKUP_TXT=$BKUP_DIR/real_time
BKUP_SUMMARY_LOG=/orabackup/$HOST_STR/backup_summary_$BKUP_MODE
BKUP_DUMMY_SCRIPT=$BKUP_DIR/"$BKUP_MODE"."$HOST_STR".script.sh
ALL_FILE_LIST=$BKUP_DIR/$HOST_STR.all_file.lst

# *** Set variables needed for sending backup output thru email
DBA_LST=$BKUP_SCR_DIR/dbas.txt
MSGFILE=$BKUP_DIR/email.txt

# *** Check if Backup Dir exists
   if [ ! -w $BKUP_DIR ]
       then echo "\n   Missing Backup Dir = $BKUP_DIR, Going to create it now... " 
            mkdir $BKUP_DIR
            status=$?
            if [ $status -ne 0 ]
              then
               echo " Can not create Backup Dir = $BKUP_DIR , aborting the backup task "
               exit1
              else echo " Backup dir =  $BKUP_DIR, was missing, just created new one "
            fi
     else  echo "\n Backup Dir exists, Going ahead with backup process, all Data will be overwritten on this dir, if exists   ">>  $BKUP_LOG
   fi


# *** Check if $HOST_STR.env file exists & Then executes the ENV File to set ORACLE Parameters
   ORAENV=/export/home/oracle/$HOST_STR.env
   if [ -r $ORAENV ]; then echo "ENV file exists : $ORAENV" 
     else  echo "Missing env file : $ORAENV , needed to set Oracle ENV " >>  $BKUP_LOG 
     exit 1
   fi

   . $ORAENV

 echo " ....................................................." >>  $BKUP_LOG
 echo " Current ORACLE env Settings : "                        >> $BKUP_LOG 
 echo " Current ORACLE_SID   : $ORACLE_SID"                    >> $BKUP_LOG
 echo " Current ORACLE_HOME  : $ORACLE_HOME"                   >> $BKUP_LOG
 echo "\n ....................................................." >> $BKUP_LOG


# *** Create  backup script
   echo $BKUP_LOG
   SCRIPT="$BKUP_SCR $HOST_STR $BKUP_DIR $NUM_OF_PROCS >> $BKUP_LOG 2>&1"
   echo $SCRIPT > $BKUP_DUMMY_SCRIPT
   chmod 700 $BKUP_DUMMY_SCRIPT 


###Starting  Backup NOW ###
   echo " Starting Backup $BKUP_MODE : ..."                     >> $BKUP_LOG
   $BIN_DIR/time -p  $BKUP_DUMMY_SCRIPT 2>$BKUP_TXT
       if [ $status -ne 0 ]
            then
            echo "Backup was not successful, please Check the LOG File= $BKUP_LOG "
            exit1
       fi 


#*** Post Backup Tasks
# *** Get the time After Backup is finished 
   BKUP_ENDTIME=`date +%m-%d-%Y__%H:%M:%S`

# *** Check backup log for errors
#   if [ "$BKUP_MODE" = "exp" ]; then
#      grep -ni -f $BKUP_SCR_DIR/error_pattern.txt $BKUP_LOG > $BKUP_ERR
#      else
#      grep -ni -f $BKUP_SCR_DIR/error_pattern.txt $BKUP_LOG > $BKUP_ERR
#   fi

# *** If error log has no entries then remove the file
#   find $BKUP_ERR -size 0 | grep $BKUP_ERR
#   if [ $? != 0 ]; then
#     BKUP_STATUS=1
#     BKUP_STAT_TXT="NOT OK"
#   else
#     rm $BKUP_ERR
#     BKUP_STATUS=0
#     BKUP_STAT_TXT="OK"
#   fi

# *** House Keeping of $BKUP_DIR, $BKUP_ARCH_DIR, $BKUP_TEMP_DIR
#################if [ "$BKUP_MODE" = "hot" ]; then
################# if [ $BKUP_STATUS = 0 ]; then
#################  # Remove '*arc.Z' files in $BKUP_ARCH_DIR which have not been accessed in 3 days
#################  $BKUP_SCR_DIR/remove_aged_files.sh $BKUP_ARCH_DIR '*arc.Z' 3 >> $BKUP_LOG 2>&1

#################  # Remove 'move*.log' files in $BKUP_TEMP_DIR which have not been accessed in 3 days
#################  $BKUP_SCR_DIR/remove_aged_files.sh $BKUP_TEMP_DIR 'move*.log' 3 >> $BKUP_LOG 2>&1

#################  # Remove 'arch*.lst' files in $BKUP_TEMP_DIR which have not been accessed in 3 days
#################  $BKUP_SCR_DIR/remove_aged_files.sh $BKUP_TEMP_DIR 'arch*.lst' 3 >> $BKUP_LOG 2>&1
################# fi
#################fi

echo " Finished Removing Old Backup Files"

#################if [ $BKUP_STATUS = 0 ]; then
#################  # Remove 'backup.[0-1]*.*' in $BKUP_DIR which have not been accessed in 14 days
#################  $BKUP_SCR_DIR/remove_aged_files.sh $BKUP_DIR 'backup.[0-1]*.*' 14 >> $BKUP_LOG 2>&1
#################fi

####echo " Finished Removing 14 days old  Files"

# *** Get Time Elapsed
   TIME_ELAPSED=`grep -i real $BKUP_TXT | awk '{print $2}' `

# *** Convert TIME_ELAPSED to minutes
   TIME_ELAPSED=`echo "$TIME_ELAPSED 60" | awk '{print $1 / $2}'`
   echo "Time elapsed (minutes): $TIME_ELAPSED" 

# *** Compute for Total Size of Database (KB) Files and compression %
   FSZ=0
      for SZ1 in `cat  $ALL_FILE_LIST | awk -F" " '{print $5}'`
        do
           FSZ=`expr $FSZ + $SZ1`
        done  

   CSZ=0
      for SZ2 in `ls -l $BKUP_DIR/*Z | awk -F" " '{print $5}'`
        do
           CSZ=`expr $CSZ + $SZ2`
        done
  
   RATIO=`echo "$FSZ $CSZ"   | awk '{print $1 - $2}'`
   RATIO=`echo "$RATIO 100"  | awk '{print $1 * $2}'`
   RATIO=`echo "$RATIO $FSZ" | awk '{print $1 / $2}'`

# *** Convert unit from KB to MB  Convert to MB ( 1024 * 1024)
   FSZ=`echo "$FSZ 1048576"   | awk '{print $1 / $2}'`   
   CSZ=`echo "$CSZ 1048576"   | awk '{print $1 / $2}'` 

   echo "Total File Size (MB): $FSZ" 
   echo "% Compression: $RATIO"     
   echo "Status: $BKUP_STATUS"     

# *** Check if $BKUP_SUMMARY_LOG , History of Backups, exists. If not, put heading in it
if [ ! -r $BKUP_SUMMARY_LOG ]; then
 echo "Summary of $BKUP_MODE backups for $HOST_STR\n" > $BKUP_SUMMARY_LOG
 echo "Start Time         Run Time (mins)  DB Size (MB)    % Compression  Status" >> $BKUP_SUMMARY_LOG
fi


# *** Write  log summary in $BKUP_SUMMARY_LOG
printf "$BKUP_STARTTIME    %12.2f     %12.2f       %4.2f        $BKUP_STAT_TXT\n" \
     $TIME_ELAPSED $FSZ $RATIO >> $BKUP_SUMMARY_LOG

# *** Mail backup log to DBAS
   echo   "Results of $HOST_STR $BKUP_MODE backup :\n"          > $MSGFILE
   echo   "Backup Start Time          : $BKUP_STARTTIME"       >> $MSGFILE
   echo   "       End   Time          : $BKUP_ENDTIME"         >> $MSGFILE
   printf "Elapsed Time (minutes)     : %3.2f\n" $TIME_ELAPSED >> $MSGFILE
   printf "DB Size              (MB)  : %3.2f\n" $FSZ          >> $MSGFILE
   printf "Compressed DB Size   (MB)  : %3.2f\n" $CSZ          >> $MSGFILE
   printf "Compression %%             : %3.2f\n" $RATIO        >> $MSGFILE
   echo   "Status                     : $BKUP_STAT_TXT "       >> $MSGFILE
   echo "\n====================================================" >> $MSGFILE

   if [ "$BKUP_STATUS" = "1" ]; then
      echo "Excerpt from error log:  $BKUP_ERR\n"              >> $MSGFILE
      head -30 $BKUP_ERR                                       >> $MSGFILE
      echo "\n====================================================" >> $MSGFILE
   fi


# *** Append the History of Backup Summary Log of backups to the email
   cat $BKUP_SUMMARY_LOG >> $MSGFILE

# *** Email log to all DBA's listed in $DBA_LST
   DBAS=`grep -v "#" $DBA_LST | awk -F"," '{printf " " $2 ","}'`
   MSG_SUBJ="$BKUP_STAT_TXT $HOST_STR $BKUP_MODE backup"
   mailx -s  "$MSG_SUBJ" $DBAS < $MSGFILE

#*** Save Backup from being overwritten fir next Run,
#    But FOllowing lines can be commented if space is an issue
#    and Backup is saved / written to tape
mv $BKUP_DIR  $BKUP_DIR"_$BKUP_STARTTIME"
if [ ! -d $BKUP_DIR ] ; then mkdir $BKUP_DIR; fi

#*** Create File for Last Backup Dir name & Location for rcp to remote Location
LAST_BACKUP_DIR=/orabackup/$HOST_STR/last_backup_dir_name_"$BKUP_MODE"_"$HOST_STR".txt
if [  -r $LAST_BACKUP_DIR ]
  then
    rm -f $LAST_BACKUP_DIR
    echo  "${BKUP_DIR}_${BKUP_STARTTIME}" > $LAST_BACKUP_DIR
fi


exit 0

