#   File Name:  bkup_compress.sh
#
#   Purpose: Compresses a set of files to a given directory 
#             
#   Assumption: The 2nd parameter is a file that contains a single-column 
#                  list of files to be compressed
#
#   Parameters:  
#       $1 SRC_FILE_LST  -  constains a single-column list of files
#       $2 OUTPUT_DIR    -  directory where the compressed files will be saved 
#
#   Created by  :  Ajay Jain  01/15/03
#   Modified by :
# 

ERRMSG="`basename $0`: syntax error "

if [ "$1" ]; then SRC_FILE_LST=$1; else echo $ERRMSG >&2; exit 1; fi
if [ "$2" ]; then OUTPUT_DIR=$2 ; else echo $ERRMSG >&2 ; exit 1; fi

cat $SRC_FILE_LST | while read LST1
  do
        CURR_FILE=`basename $LST1`
        STARTTIME=`date +%m%d%y.%H:%M:%S`    
        echo "\n Compressing $LST1 TO $OUTPUT_DIR/$CURR_FILE.Z ........" 
        compress < $LST1 > "$OUTPUT_DIR"/"$CURR_FILE".Z 
        STATUS=$?
         if [ $STATUS -ne 0 ]
          then
             echo " \ncompressing of the file $CURR_FILE, failed, could be no space left on disk "
             echo " exiting with status = $STATUS "
             exit 1
        fi
        echo "     Status: $STATUS "
        ENDTIME=`date +%m%d%y.%H:%M:%S`
        COMPRESSED_SZ=`ls -l $OUTPUT_DIR/$CURR_FILE.Z | awk  '{print $5}'` 
        FILE_SZ=`ls -l $LST1 | awk  '{print $5}'` 

        echo "     File Sz           : $FILE_SZ"  
        echo "     Compressed Sz     : $COMPRESSED_SZ" 
        echo "     Start Time        : "$STARTTIME 
        echo "     End   Time        : "$ENDTIME 
  done


