#   Name:  cold_bkup.sh
#   Purpose:  Runs several scripts to perform a cold backup and generate
#              a restore script. 
#   Assumption:  init.ora's parameter, user_dump_dest only contains
#                the given instance's trace files
#   Parameters:  
#                $1   HOST STRING
#                $2   Backup Directory (optional)
#                $3   Number of parallel processes (default=3, max=9)  
#   Created by  :  Ajay Jain  01/15/03
#   Modified by :
#
# How to run:
# /orabackup/scripts/cold_bkup.sh system_password HOST_STR | tee logfile


ERRMSG="`basename $0`: syntax error"

if [ "$1" ] ; then HOST_STR=$1 ;     else echo $ERRMSG >&2 ; exit 1;  fi        
if [ "$2" ] ; then BKUP_DIR=$2 ;     else echo $ERRMSG >&2 ; exit 1;  fi 
if [ "$3" ];  then NUM_OF_PROCS=$3 ; else NUM_OF_PROCS=5   ; fi

BKUP_SCR=/orabackup/scripts

DFILE_LST=$BKUP_DIR/$HOST_STR.dfile.lst
CTLFILE_LST=$BKUP_DIR/$HOST_STR.ctlfile.lst
REDOLOGS_LST=$BKUP_DIR/$HOST_STR.redo.lst
TEMPFILE_LST=$BKUP_DIR/$HOST_STR.tempfile.lst
FILE_COUNT_LST=$BKUP_DIR/$HOST_STR.filecount.lst
DETAILDFILE_LST=$BKUP_DIR/$HOST_STR.detailed_dfile_info.lst
RESTORE_SCR=$BKUP_DIR/RESTORE_$HOST_STR.sh
INST_STAT=$BKUP_DIR/$HOST_STR.instance_status.log
DUPFILE_LST=$BKUP_DIR/$HOST_STR.dupfile.lst


GROUPFILE_LST=$BKUP_DIR/$HOST_STR.groupfile.lst
GROUPFILE_LST1=$BKUP_DIR/$HOST_STR.groupfile1.lst
GROUPFILE_LST2=$BKUP_DIR/$HOST_STR.groupfile2.lst
GROUPFILE_LST3=$BKUP_DIR/$HOST_STR.groupfile3.lst
GROUPFILE_LST4=$BKUP_DIR/$HOST_STR.groupfile4.lst
GROUPFILE_LST5=$BKUP_DIR/$HOST_STR.groupfile5.lst
GROUPFILE_LST6=$BKUP_DIR/$HOST_STR.groupfile6.lst
GROUPFILE_LST7=$BKUP_DIR/$HOST_STR.groupfile7.lst
GROUPFILE_LST8=$BKUP_DIR/$HOST_STR.groupfile8.lst
GROUPFILE_LST9=$BKUP_DIR/$HOST_STR.groupfile9.lst


BKUP_STARTTIME=`date +%m%d%y.%H:%M:%S`

echo " "
echo "Starting cold backup of $HOST_STR... :$BKUP_STARTTIME"


# *** Delete previous backups in backup directory
rm -f $BKUP_DIR/*.Z \
      $BKUP_DIR/*.log \
      $BKUP_DIR/*.trc \
      $BKUP_DIR/*.lst \
      $BKUP_DIR/"$HOST_STR"*.ctl \
      $BKUP_DIR/cntr*.dbf \
      $BKUP_DIR/*.ora



# *** Check if instance is up, 
   echo "\nChecking if instance is up ..."
   INSTANCE_STATUS=`$BKUP_SCR/check_instance_up.sh $HOST_STR > $INST_STAT`
     if [ "$INSTANCE_STATUS" = "1" ]; then
        echo "     Instance is not up.  Quitting COLD BACKUP  of $HOST_STR...." 
        echo "     Status: $INSTANCE_STATUS"
        exit 1 
    else
        echo "     Status : INSTANCE  is up, continueing   with COLD Backup .."
     fi  

# *** Check if file_name ( without path name) is duplicate or not
# *** Genearte file for Duplicate    
     echo   "\nCheck if file_name ( without path name) is duplicate or not"
     $BKUP_SCR/get_duplicate_file.sh  $DUPFILE_LST 
     ls -l $DUPFILE_LST
# *** Begin Check for duplicate file names
     DUP_STATUS=`$BKUP_SCR/check_duplicate_file.sh  $DUPFILE_LST $HOST_STR $BKUP_DIR`
     if [ "$DUP_STATUS" = "1" ]; then
        echo "     Dupliate file is found, check $DUPFILE_LOG for details...."
        echo "     Status: $DUP_STATUS"
        exit 1
    else
        echo "     Status : NO Duplicate Files (dbf,ctl,log) found .."
     fi
 
# *** Backup init.ora , spfile.ora  and Control File to trace
   echo '\nBacking up init.ora and control file to trace ...'
   CTL_TRACE_DIR=`$BKUP_SCR/bkup_ctl_totrc.sh`
   CTL_TRACE_FILE=`ls -1t $CTL_TRACE_DIR | head -1`
   cp -p $CTL_TRACE_DIR/$CTL_TRACE_FILE $BKUP_DIR/.
   if [ -r $ORACLE_HOME/dbs/init$HOST_STR.ora ]; then cp -p $ORACLE_HOME/dbs/init$HOST_STR.ora $BKUP_DIR/. ; fi 
   if [ -r $ORACLE_HOME/dbs/spfile$HOST_STR.ora ]; then cp -p $ORACLE_HOME/dbs/spfile$HOST_STR.ora $BKUP_DIR/. ; fi 
   if [ -r $ORACLE_HOME/dbs/orapw$HOST_STR ]; then cp -p $ORACLE_HOME/dbs/orapw$HOST_STR $BKUP_DIR/. ; fi

# *** Create file count for all files ( control, log, temp, data files) for info only
   echo "\nCreating File Count list ...$FILE_COUNT_LST"
   $BKUP_SCR/get_file_count.sh $FILE_COUNT_LST
   echo "     Status: $?"
   ls -l $FILE_COUNT_LST

# *** Generate datafile detailed information purposes
# *** rewrite the query, order by biggest tablespace first
#   echo "\nGenerating DETAILED datafile information ...$DETAILDFILE_LST"
#   $BKUP_SCR/generate_datafile_info.sh $DETAILDFILE_LST 
#   echo "     Status: $?"

# *** Create instance Restore script
   echo "\nCreating instance Restore script ... $RESTORE_SCR"
   echo "     Also generatiing lists for control, redo logs, temp , database files " 
   $BKUP_SCR/cr_restore.sh $HOST_STR $BKUP_DIR
   echo "     Status: $?"
   ls -l $RESTORE_SCR

# *** Get list of control files for COLD BACKUP 
   echo "\nChecking for the List of control files ... $CTLFILE_LST"
   if [ -r $CTLFILE_LST ]
     then 
        echo "     Control File list $CTLFILE_LST  EXISTS & was created by Restore Script" 
     else  
        echo "     Getting list of control files ... $CTLFILE_LST"
        $BKUP_SCR/get_ctlfiles.sh $CTLFILE_LST
    fi
   echo "     Status: $?"

# *** Get list of temp data files for  COLD BACKUP
   echo "\nChecking for the List of Temp TBS temp files ... $TEMPFILE_LST"
   if [ -r $TEMPFILE_LST ]
     then
        echo "     TEMP File list $TEMPFILE_LST  EXISTS & was created by Restore Script"
     else
        echo "     Getting list of TEMP data files ... $TEMPFILE_LST"
        $BKUP_SCR/get_tempfiles.sh $TEMPFILE_LST
   fi
   echo "     Status: $?"

# *** Generate a list of datafiles and redologs  using database table , for COLD BACKUP
# *** this required for parallel compression
   echo "\nCreate Table for Grouping files for parallel compression/copy ..."
   $BKUP_SCR/group_filesz.sh $HOST_STR $GROUPFILE_LST $NUM_OF_PROCS
   echo "     Status: $?"


# *** Backup a Binary Control File then Shutdown DB for COLD BACKUP
   echo "\nCreating  binary control file then shushutdown Database ..."
   $BKUP_SCR/shutdown_db.sh $HOST_STR $BKUP_DIR/$HOST_STR`date +%m%d%y`.ctl 
   echo "     Status: $?"
   ls -l $BKUP_DIR/$HOST_STR`date +%m%d%y`.ctl 

# *** Check if instance is DOWN and it's ready for backup,
   echo "\nChecking if instance is DOWN to perform COLD backup..."
   INSTANCE_STATUS=`$BKUP_SCR/check_instance_up.sh $HOST_STR >> $INST_STAT`
     if [ "$INSTANCE_STATUS" = "0" ]; then
        echo "     Instance is UP, so can not perform COLD BACKUP. Quitting COLD BACKUP  of $HOST_STR...."
        echo "     Status: $INSTANCE_STATUS"
         exit 1
     else
        echo "     Status : Instanec is DOWN, continueing  with COLD Backup .."

     fi
    echo "     Status: $?"
 echo "\n ###############   Begin to COMPRESS the files now ...   ############"
# *** Backup Control files 
   echo "\n Backing up Control files ..."
   $BKUP_SCR/bkup_compress.sh $CTLFILE_LST $BKUP_DIR | tee  $CTLFILE_LST.log &
   JOBCONTROL=$!
   echo "     copying controlfiles Proc ID : " $JOBCONTROL
   wait $JOBCONTROL
   echo "     Control File Backup Status: $?"


# *** Backup TEMP data files
   echo "\n Backing up TEMP files ..."
$BKUP_SCR/bkup_compress.sh $TEMPFILE_LST $BKUP_DIR | tee $TEMPFILE_LST.log &
   JOBTEMPFILE=$!
   echo "     compressing  Temp Data Files Proc ID : " $JOBTEMPFILE
   wait $JOBTEMPFILE
   echo "     Temp File Backup Status: $?"

# *** Invoke $NUM_OF_PROCS parallel processes that compress
#        datafiles and redologs to backup directory 
echo "\nInvoking $NUM_OF_PROCS processes for parallel compression/copy ..."
   grep "SET1" $GROUPFILE_LST | awk -F~ '{print $2}' > $GROUPFILE_LST1
   grep "SET2" $GROUPFILE_LST | awk -F~ '{print $2}' > $GROUPFILE_LST2
   grep "SET3" $GROUPFILE_LST | awk -F~ '{print $2}' > $GROUPFILE_LST3
   grep "SET4" $GROUPFILE_LST | awk -F~ '{print $2}' > $GROUPFILE_LST4
   grep "SET5" $GROUPFILE_LST | awk -F~ '{print $2}' > $GROUPFILE_LST5
   grep "SET6" $GROUPFILE_LST | awk -F~ '{print $2}' > $GROUPFILE_LST6
   grep "SET7" $GROUPFILE_LST | awk -F~ '{print $2}' > $GROUPFILE_LST7
   grep "SET8" $GROUPFILE_LST | awk -F~ '{print $2}' > $GROUPFILE_LST8
   grep "SET9" $GROUPFILE_LST | awk -F~ '{print $2}' > $GROUPFILE_LST9


$BKUP_SCR/bkup_compress.sh $GROUPFILE_LST1 $BKUP_DIR > $GROUPFILE_LST1.log &  
   JOB1=$!
   echo "Job #1 Proc ID : " $JOB1

$BKUP_SCR/bkup_compress.sh $GROUPFILE_LST2 $BKUP_DIR > $GROUPFILE_LST2.log &  
   JOB2=$!
   echo "Job #2 Proc ID : " $JOB2

$BKUP_SCR/bkup_compress.sh $GROUPFILE_LST3 $BKUP_DIR > $GROUPFILE_LST3.log &  
   JOB3=$!
   echo "Job #3 Proc ID : " $JOB3

$BKUP_SCR/bkup_compress.sh $GROUPFILE_LST4 $BKUP_DIR > $GROUPFILE_LST4.log &
   JOB4=$!
   echo "Job #4 Proc ID : " $JOB4

$BKUP_SCR/bkup_compress.sh $GROUPFILE_LST5 $BKUP_DIR > $GROUPFILE_LST5.log &
   JOB5=$!
   echo "Job #5 Proc ID : " $JOB5

$BKUP_SCR/bkup_compress.sh $GROUPFILE_LST6 $BKUP_DIR > $GROUPFILE_LST6.log &
   JOB6=$!
   echo "Job #6 Proc ID : " $JOB6

$BKUP_SCR/bkup_compress.sh $GROUPFILE_LST7 $BKUP_DIR > $GROUPFILE_LST7.log &
   JOB7=$!
   echo "Job #7 Proc ID : " $JOB7

$BKUP_SCR/bkup_compress.sh $GROUPFILE_LST8 $BKUP_DIR > $GROUPFILE_LST8.log &
   JOB8=$!
   echo "Job #8 Proc ID : " $JOB8

$BKUP_SCR/bkup_compress.sh $GROUPFILE_LST9 $BKUP_DIR > $GROUPFILE_LST9.log &
   JOB9=$!
   echo "Job #9 Proc ID : " $JOB9

   wait $JOB1
   wait $JOB2
   wait $JOB3
   wait $JOB4
   wait $JOB5
   wait $JOB6
   wait $JOB7
   wait $JOB8
   wait $JOB9
   
   echo "\nDataFiles Compression Status from Process#1 : "
   cat $GROUPFILE_LST1.log
   echo "\nDataFiles Compression Status from Process#2 : "
   cat $GROUPFILE_LST2.log
   echo "\nDataFiles Compression Status from Process#3 : "
   cat $GROUPFILE_LST3.log
   echo "\nDataFiles Compression Status from Process#4 : "
   cat $GROUPFILE_LST4.log
   echo "\nDataFiles Compression Status from Process#5 : "
   cat $GROUPFILE_LST5.log
   echo "\nDataFiles Compression Status from Process#6 : "
   cat $GROUPFILE_LST6.log
   echo "\nDataFiles Compression Status from Process#7 : "
   cat $\nGROUPFILE_LST7.log
   echo "DataFiles Compression Status from Process#8 : "
   cat $GROUPFILE_LST8.log
   echo "\nDataFiles Compression Status from Process#9 : "
   cat $GROUPFILE_LST9.log

echo "\nCOLD Backup of $HOST_STR is Finished  at ......`date +%m-%d-%y.%H:%M:%S` "

# *** Startup the database
echo "\nBringing up the database ... "
$BKUP_SCR/startup_db.sh 

# *** Report Backup Start/End Time
echo " "
echo "Cold Backup of $HOST_STR ended."
echo "Start time:  $BKUP_STARTTIME"
echo "End   time:  `date +%m%d%y.%H:%M:%S`"  


