#   File Name: cr_control_file_for_clone_db.sh 
#
#   Purpose: Generate the " Create Control file for Cloning the instance " 
#
#   Created by  :  Ajay Jain  01/15/03
#   Modified by :#            
#

ERRMSG="`basename $0`: syntax error  "
if [ "$1" ] ;  then HOST_STR=$1  ; else echo $ERRMSG >&2 ; exit 1 ; fi
if [ "$2" ] ;  then BACKUP_DIR=$2  ; else echo $ERRMSG >&2 ; exit 1 ; fi

SPOOL_FILE=$BACKUP_DIR/${HOST_STR}_cr_db_controlfile.sql 
TEMP1=$BACKUP_DIR/${HOST_STR}_temp.lst
rm -f $SPOOL_FILE 
rm -f $TEMP1

echo "\n Assumptions :  Rollback Tablesspace Name =  RBS "
echo "                Temporary Tablesspace Name = TEMP"
echo "  TEMP tablespace are not included in the $SPOOL_FILE"

sqlplus -s  " /as sysdba  " > $SPOOL_FILE << EOF

set serveroutput on size 1000000               
set echo off
set feedback off
set heading off
set trimspool on
set linesize 132
set pagesize 0


Declare 
v_character_set    varchar2(4000); 
v_file_name        varchar2(513);
v_max_file_id      number;
v_file_id          number;

Cursor C1 is
select value$ from sys.props$ where name='NLS_CHARACTERSET'; 

Cursor C2 is 
  select max ( File_id )  from dba_data_files;

Cursor C3 is
select substr (file_name , instr( file_name, '/', -1) +1 ,  length (file_name)  )  , file_id
from dba_data_files
where tablespace_name not in ( 'TEMP')
 order by file_id;



BEGIN
  open c1;
   fetch c1 into v_character_set;
  close c1;
  
  open c2;
   fetch c2 into v_max_file_id;
  close c2;
    dbms_output.put_line ('---------------------------------------------------------------------- '); 
    dbms_output.put_line ('-- This controlfile does not include data files from TEMP tablespaces');
    dbms_output.put_line ('---------------------------------------------------------------------- ');
    dbms_output.put_line ('   STARTUP NOMOUNT; ');
    dbms_output.put_line ('create controlfile SET database TARGET_SID resetlogs noarchivelog');
    dbms_output.put_line ('   maxlogfiles 16 ');
    dbms_output.put_line ('   maxlogmembers 2 ');
    dbms_output.put_line ('   maxdatafiles  1000 ');
    dbms_output.put_line ('   maxinstances  1 ');
    dbms_output.put_line ('   maxloghistory 3176 ');
    dbms_output.put_line ('LOGFILE ');
    dbms_output.put_line ('  group 1 ( ');
    dbms_output.put_line ('     '||''''||'TARGET_DBF_DIR/log01a.dbf'||''''||', ');
    dbms_output.put_line ('     '||''''||'TARGET_DBF_DIR/log01b.dbf'||''''||' ) size 10M,');
    dbms_output.put_line ('  group 2 ( ');
    dbms_output.put_line ('     '||''''||'TARGET_DBF_DIR/log02a.dbf'||''''||', ');
    dbms_output.put_line ('     '||''''||'TARGET_DBF_DIR/log02b.dbf'||''''||' ) size 10M,');
    dbms_output.put_line ('  group 3 ( ');
    dbms_output.put_line ('     '||''''||'TARGET_DBF_DIR/log03a.dbf'||''''||', ');
    dbms_output.put_line ('     '||''''||'TARGET_DBF_DIR/log03b.dbf'||''''||' ) size 10M');
    dbms_output.put_line ('DATAFILE ');

open c3;
  LOOP  
    fetch c3 into v_file_name, v_file_id;
    exit when c3%NOTFOUND;
    if  v_file_id < v_max_file_id 
      then
         dbms_output.put_line ('     '||''''||'TARGET_DBF_DIR/'|| v_file_name ||''''||', ');
    elsif 
        v_file_id =   v_max_file_id 
      then        
         dbms_output.put_line ('     '||''''||'TARGET_DBF_DIR/'|| v_file_name ||'''');
         dbms_output.put_line (' character set '||v_character_set ||' ; ');
         dbms_output.put_line ('                          ');
         dbms_output.put_line ('---------OPEN  Database ------- ');
         dbms_output.put_line (' alter database open resetlogs ; ' );
    else 
          dbms_output.put_line ('----------------------------------------- ');
    end if; 
  END LOOP;
close c3;


END;
/

EOF

# *** Following does the formatting of output file to make more readable 
F1="'TARGET_DBF_DIR"
F2="    'TARGET_DBF_DIR"
cat $SPOOL_FILE | sed "s,$F1,$F2,g" > $TEMP1
mv $TEMP1 $SPOOL_FILE

chmod 400 $SPOOL_FILE
echo " control file = $SPOOL_FILE "

  
  
  
  

