#   Name: cr_restore.sh 
#   Purpose:  generate restore script. 
#
#   Assumption:  
#                
#
#   Created by  :  Ajay Jain  01/15/03
#   Modified by :
#


ERRMSG="`basename $0`: syntax error "

if [ "$1" ]; then HOST_STR=$1;  else echo $ERRMSG >&2; exit 1; fi  
if [ "$2" ]; then BKUP_DIR=$2;  else echo $ERRMSG >&2; exit 1; fi 

BKUP_SCR=/orabackup/scripts
DFILE_LST=$BKUP_DIR/$HOST_STR.dfile.lst
CTLFILE_LST=$BKUP_DIR/$HOST_STR.ctlfile.lst
REDOLOGS_LST=$BKUP_DIR/$HOST_STR.redo.lst
TEMPFILE_LST=$BKUP_DIR/$HOST_STR.tempfile.lst
RESTORE_SCR=$BKUP_DIR/RESTORE_$HOST_STR.sh
ALL_FILE_LIST=$BKUP_DIR/$HOST_STR.all_file.lst
DFILE_FTP_LST1=$BKUP_DIR/$HOST_STR.dfile_ftp_tmp.lst
DFILE_FTP_LST2=$BKUP_DIR/ftp_list.txt

BKUP_STARTTIME=`date +%m%d%y.%H:%M:%S`
echo "     creating database restore script ... :$BKUP_STARTTIME"

if [ -r $RESTORE_SCR ]; then rm -f $RESTORE_SCR; fi

# *** Create a restore script
echo "# Restore script for $HOST_STR"    > $RESTORE_SCR
echo "# Script creation Date: `date`"   >> $RESTORE_SCR
echo " " >> $RESTORE_SCR
echo 'echo "Start time: `date`"'        >> $RESTORE_SCR
echo " "                                >> $RESTORE_SCR

# *** Create list of datafiles for cold copy
   echo "\nGetting list of datafiles ..."
   $BKUP_SCR/get_datafiles.sh $DFILE_LST
   echo "     Status: $?"
   ls -l  $DFILE_LST


# *** Create list of control files for cold copy
   echo "\nGetting list of control files ..."
   $BKUP_SCR/get_ctlfiles.sh $CTLFILE_LST
   echo "     Status: $?"
   ls -l  $CTLFILE_LST


# *** Create list of redo logs for cold copy
   echo "\nGetting list of redologs ..."
   $BKUP_SCR/get_redologs.sh $REDOLOGS_LST
   echo "     Status: $?"
   ls -l  $REDOLOGS_LST


# *** Get list of temp data files for  COLD BACKUP Restore scripts
   echo "\nGetting list of tempfiles ...$TEMPFILE_LST"
   $BKUP_SCR/get_tempfiles.sh $TEMPFILE_LST
   echo "     Status: $?"
   ls -l  $TEMPFILE_LST

########## EXECUTION ######################
# ***  control files for Restore script 
echo " " >> $RESTORE_SCR
echo " " >> $RESTORE_SCR
echo " ##########------------------- Section:  CONTROLFILE  Restore -------------------"   >> $RESTORE_SCR
cat $CTLFILE_LST | while read CONTROLFILE
  do
    ls -l   $CONTROLFILE  >> $ALL_FILE_LIST
    CURR_FILE=`basename $CONTROLFILE`
    echo " "                            >> $RESTORE_SCR
    echo "echo 'Restoring $CONTROLFILE ... '" >> $RESTORE_SCR
    echo "#### uncompress < $BKUP_DIR/$CURR_FILE.Z > $CONTROLFILE" >> $RESTORE_SCR
    echo 'echo "Status: $?"'            >> $RESTORE_SCR
  done

# ***  Redo Log files for Restore script
echo " " >> $RESTORE_SCR
echo " " >> $RESTORE_SCR
echo " ##########------------------- Section:  RE-DO LOGS  Restore -------------------"   >> $RESTORE_SCR
cat $REDOLOGS_LST | while read REDOLOG
  do
   ls -l   $REDOLOG  >> $ALL_FILE_LIST
   CURR_FILE=`basename $REDOLOG`
    echo " "                           >> $RESTORE_SCR
    echo "echo 'Restoring $REDOLOG ... '" >> $RESTORE_SCR
    echo "#### uncompress < $BKUP_DIR/$CURR_FILE.Z > $REDOLOG"    >> $RESTORE_SCR
    echo 'echo "Status: $?"'           >> $RESTORE_SCR
  done          

# ***  Temp  data files  for Restore script
echo " " >> $RESTORE_SCR
echo " " >> $RESTORE_SCR
echo " ##########------------------- Section:   TEMPFILES  Restore -------------------"   >> $RESTORE_SCR
cat $TEMPFILE_LST | while read TEMPFILE
  do
    ls -l   $TEMPFILE  >> $ALL_FILE_LIST 
    CURR_FILE=`basename $TEMPFILE`
    echo " " >> $RESTORE_SCR
    echo "echo 'Restoring $TEMPFILE ... '"  >> $RESTORE_SCR
    echo "#### uncompress < $BKUP_DIR/$CURR_FILE.Z > $TEMPFILE"  >> $RESTORE_SCR
    echo 'echo "Status: $?"'            >> $RESTORE_SCR
  done

# ***  Datafiles files for Restore script
echo " " >> $RESTORE_SCR
echo " " >> $RESTORE_SCR
echo " ##########------------------- Section:  DATAFILE   Restore -------------------"   >> $RESTORE_SCR
cat $DFILE_LST | while read DATAFILE
  do
    ls -l   $DATAFILE  >> $ALL_FILE_LIST  
    CURR_FILE=`basename $DATAFILE`
    echo " " >> $RESTORE_SCR
    echo "echo 'Restoring $DATAFILE ... '"  >> $RESTORE_SCR
    echo "#### uncompress < $BKUP_DIR/$CURR_FILE.Z > $DATAFILE"  >> $RESTORE_SCR
    echo 'echo "Status: $?"'            >> $RESTORE_SCR
  done

echo " " >> $RESTORE_SCR
echo "echo 'Starting up the database ....'" >> $RESTORE_SCR
echo "# *** $BKUP_SCR/startup_db.sh $HOST_STR" >> $RESTORE_SCR 
echo  " " >> $RESTORE_SCR
echo 'echo "Restore End time: `date`"' >> $RESTORE_SCR 
chmod 400 $RESTORE_SCR


# ***  Datafiles files for FTP  ( Only data files, without TEMP, RBS, REDO Logs, Control files )
        $BKUP_SCR/get_ftp_dfiles.sh $DFILE_FTP_LST1
        echo "  Generatin of ftp list    Status: $?"
        cat $DFILE_FTP_LST1 | while read DATAFILE
        do
          CURR_FILE=`basename $DATAFILE`
          echo $CURR_FILE >> $DFILE_FTP_LST2
         done
   rm $DFILE_FTP_LST1




