#  File Name  :  exp_bkup.sh
#  Desciption :  Runs an Oracle Export given the following parameter/s:
#                   $1  SYSTEM PASSWORD
#                   $2  ORACLE_SID    
#                   $3  Backup Directory (optional)
#
#
#  How to run:
#   1) run /home/oracle/$ORACLE_SID.env
#   2) run /orabackup/scripts/exp_bkup.sh  system_password host_str <bkup dir>  

#   Created by  :  Ajay Jain  01/15/03
#   Modified by :
###   use     _disable_logging=true  for import 

ERRMSG="`basename $0`: syntax error: exp_bkup.sh system_password host_string <b
kup dir>"

if [ "$1" ]
then SYS_PWD=$1
else echo $ERRMSG >&2
  exit 1
fi

if [ "$2" ]
then HOST_STR=$2
else echo $ERRMSG >&2
  exit 1
fi

if [ "$3" ]
then EXP_DIR=$3
else EXP_DIR=/orabackup/$HOST_STR/exp
fi                                    

BKUP_SCR_DIR=/orabackup/scripts
EXP_DIR=/orabackup/$HOST_STR/exp
EXP_FILE=$EXP_DIR/$HOST_STR`date +%m%d%y`
EXP_PARFILE=$BKUP_SCR_DIR/exp_parfile.txt
EXP_PIPE=$EXP_DIR/"$HOST_STR"_epipe
SPLIT_PIPE=$EXP_DIR/"$HOST_STR"_spipe
TEMP_DIR=$EXP_DIR
SPLIT_SIZE=500m

BKUP_STARTTIME=`date +%m%d%y.%H:%M:%S`

echo "Starting Export of $HOST_STR... :$BKUP_STARTTIME"

# *** Check if instance is up before running export
   echo "\nChecking if instance is up..."
   INSTANCE_STATUS=`$BKUP_SCR_DIR/check_instance_up.sh $HOST_STR`
   if [ "$INSTANCE_STATUS" = "1" ]; then
      echo "BACKUP ERROR: Cannot perform Oracle Export on $HOST_STR, instance maybe down."
      echo "Status: 1"
   exit 1
   fi

# *** Check if SYSTEM password is valid
echo "\nChecking if SYSTEM password is valid..."
   SYSTEMPASSWD_VALID=`$BKUP_SCR_DIR/check_system_passwd.sh $SYS_PWD $HOST_STR \
                    $EXP_DIR/check_system_passwd.sh.log`
   if [ "$SYSTEMPASSWD_VALID" = "1" ]; then
      echo "BACKUP ERROR: Invalid SYSTEM password, cannot perform EXP backup."
      echo "Status: $SYSTEMPASSWD_VALID"
      exit 1
   fi        

# *** Check if export pipe exists before deleting it 
   if [ -r $TEMP_DIR/$EXP_PIPE ]; then 
      rm $TEMP_DIR/$EXP_PIPE
   fi

# *** Delete all files in export directory which filename starts with HOST_STR 
   if [ -r $EXP_DIR/"$HOST_STR"* ]; then
      rm $EXP_DIR/"$HOST_STR"*
   fi

# *** Create a named pipes for export
   mknod $EXP_PIPE p
   mknod $SPLIT_PIPE p

# *** Compress the export pipe 
   compress < $EXP_PIPE > $SPLIT_PIPE &

# *** Split the compressed pipe into files of size not more than $SPLIT_SIZE
   split -b"$SPLIT_SIZE" $SPLIT_PIPE $EXP_FILE.dmp.Z. &

# *** Get the job number of the split background process   
   SPLIT_BGROUND_JOBNUM=$!

# *** Begin Export
   exp system/$SYS_PWD@$HOST_STR file=$EXP_PIPE log=$EXP_FILE.log parfile=$EXP_PARFILE &

### Test Export Script
#####exp system/manager buffer=204857600 compress=n direct=y consistent=n tables=inv.mtl_material_transactions log=t1.log &

# *** Wait for the split background process to complete before proceeding
   wait $SPLIT_BGROUND_JOBNUM


# *** Generate CREATE TBSP script
   echo " "
   echo "Generating TABLESPACE build script..."
   $BKUP_SCR_DIR/generate_create_tbsp_scr.sh \
              $SYS_PWD $HOST_STR $EXP_FILE.tbsp.sql

# *** Copy Init.ora
   echo " "
   echo "Copying Init.ora ...."
   cp -p $ORACLE_HOME/dbs/init"$HOST_STR".ora $EXP_FILE.init.ora
   echo "Status : $?"

# *** Get size DB
   DBFILE_SZ=`$BKUP_SCR_DIR/get_dbfilesz.sh $SYS_PWD $HOST_STR`

# *** Get size of compressed dump file
   CSZ=0
   for SZ in `ls -1 $EXP_FILE.dmp.Z.[a-z]* | awk '{print $5}'`
      do
         CSZ=`expr $CSZ + $SZ`
      done

# *** Generate Export Report
   echo "\nExport of $HOST_STR ended."
   echo "DB File Sz    (KB): $DBFILE_SZ"
   echo "Compressed Sz (KB): $CSZ"
   echo "Start time:  $BKUP_STARTTIME"
   echo "End   time:  `date +%m%d%y.%H:%M:%S`"


