
#  File Name  :  export.sh
#  Desciption :  Runs an Oracle Export given the following parameter/s:
#
#   Created by  :  Ajay Jain  01/15/03
#   Modified by :
###   use init.ora    _disable_logging=true  for import 

echo "\n Syntax for export : "
echo "export.sh System_Password Instance_Name Export_Type(full/schema/table) DMP_Name(Optional) par_file_name (Optional)"
echo "\n ----------------------------------------------------------------------------------------" 
echo "        Parmeter file for schema = parfile_schema.txt (if not specified with export )"
echo "        Parmeter file for tables = parfile_table.txt  (if not specified with export ) "
echo "\n   Examples: export.sh manager RPTPROD full   "
echo "              export.sh manager RPTPROD full  dbdmp "
echo "\n              export.sh manager RPTPROD schema " 
echo "              export.sh manager RPTPROD schema gldmp"
echo "              export.sh manager RPTPROD schema gldmp  par_gl.txt"
echo "\n              export.sh manager RPTPROD table "
echo "              export.sh manager RPTPROD table abcdmp"
echo "              export.sh manager RPTPROD table abcdmp  par_tab.txt"
echo "\n ----------------------------------------------------------------------------------------"
echo "\n "


if [ "$1" ]; then SYS_PWD=$1; else echo  "  Error : System Password is missing"  >&2; exit 1; fi
if [ "$2" ]; then HOST_STR=$2; else echo "  Error : DataBase Name is Missing"  >&2; exit 1; fi
if [ "$3" = 'full' -o "$3" = 'schema' -o "$3" = 'table' ]; then EXP_TYPE=$3;
  else echo "  Error : Export Type is missing (full/schema/table) "  >&2 ;exit 1; fi

BKUP_SCR_DIR=/orabackup/scripts
EXP_DIR=/orabackup/$HOST_STR/exp
EXP_PIPE=$EXP_DIR/"$HOST_STR"_epipe
SPLIT_PIPE=$EXP_DIR/"$HOST_STR"_spipe
TEMP_DIR=$EXP_DIR
SPLIT_SIZE=500m

# *** Assign Dump File Name  ( Default $EXP_TYPEE)
if [ "$3" = "full" ]
  then
      if [ "$4" ]; then EXP_FILE=$EXP_DIR/exp_${4}_`date +%m%d%y_%H:%M`;   echo " export dmp file name   = $EXP_FILE "
                   else EXP_FILE=$EXP_DIR/exp_full_`date +%m%d%y_%H:%M`; echo " export dmp file name   = $EXP_FILE "
      fi
  elif [ "$3" = "schema" ]
    then
      if [ "$4" ]; then EXP_FILE=$EXP_DIR/exp_${4}_`date +%m%d%y_%H:%M`;    echo " export dmp file name   = $EXP_FILE "
                   else EXP_FILE=$EXP_DIR/exp_schema_`date +%m%d%y_%H:%M`; echo " export dmp file name   = $EXP_FILE "
      fi
  elif [ "$3" = "table" ]
    then
      if [ "$4" ]; then EXP_FILE=$EXP_DIR/exp_${4}_`date +%m%d%y_%H:%M`;   echo " export dmp file name   = $EXP_FILE "
                   else EXP_FILE=$EXP_DIR/exp_table_`date +%m%d%y_%H:%M`; echo " export dmp file name   = $EXP_FILE "
      fi
  else  echo " unable to set EXP_FILE name, exiting " ; exit 1;
fi

echo " export file will be compressed & then it will be spillted at split size = $SPLIT_SIZE "


# ***  Assign Parameter file Name  ( Default : parfile_$EXP_MODE.txt )
if [ "$3" = 'schema' ]
  then
    if [ "$5" ]; then PARFILE=$BKUP_SCR_DIR/$5 ; echo " schema export parfile = $PARFILE"
                 else PARFILE=$BKUP_SCR_DIR/parfile_schema.txt;  echo " schema export parfile = $PARFILE"
    fi
elif [ "$3" = 'table' ]
  then
    if [ "$5" ]; then PARFILE=$BKUP_SCR_DIR/$5 ;  echo " table export parfile  = $PARFILE"
                 else PARFILE=$BKUP_SCR_DIR/parfile_table.txt;  echo " table export parfile  = $PARFILE"

    fi
fi
BKUP_STARTTIME=`date +%m%d%y.%H:%M:%S`

echo "\nStarting Export of $HOST_STR... "

# *** Check if Backup Dir exists
   if [ ! -w $EXP_DIR ]
       then echo "\n   Missing Backup Dir = $EXP_DIR, Going to create it now... "
            mkdir $EXP_DIR
            status=$?
            if [ $status -ne 0 ]
              then
               echo " Can not create Export Dir = $BKUP_DIR , aborting the export task "
               exit1
              else echo " Backup dir =  $EXP_DIR, was missing, just created new one "
            fi
     else  echo "\n Export Dir exists, Going ahead with export process "
   fi



# *** Check if instance is up before running export
   echo "\nChecking if instance is up..."
   INSTANCE_STATUS=`$BKUP_SCR_DIR/check_instance_up.sh $HOST_STR`
   if [ "$INSTANCE_STATUS" = "1" ]; then
      echo "BACKUP ERROR: Cannot perform Oracle Export on $HOST_STR, instance maybe down."
      echo "Status: 1"
   exit 1
   fi

# *** Check if SYSTEM password is valid
echo "\nChecking if SYSTEM password is valid..."
#   SYSTEMPASSWD_VALID=`$BKUP_SCR_DIR/check_system_passwd.sh $SYS_PWD $HOST_STR \
#                    $EXP_DIR/check_system_passwd.sh.log`
#   if [ "$SYSTEMPASSWD_VALID" = "1" ]; then
#      echo "BACKUP ERROR: Invalid SYSTEM password, cannot perform EXP backup."
#      echo "Status: $SYSTEMPASSWD_VALID"
#      exit 1
#   fi        


# *** Create a named pipes for export
echo "\n Add in path for location of mknod, if already not done so ( usual location = /usr/sbin ) "
   rm -f $EXP_PIPE
   rm -f $SPLIT_PIPE
   mknod $EXP_PIPE p
   mknod $SPLIT_PIPE p

# *** Compress the export pipe 
   compress < $EXP_PIPE > $SPLIT_PIPE &

# *** Split the compressed pipe into files of size not more than $SPLIT_SIZE
   split -b"$SPLIT_SIZE" $SPLIT_PIPE $EXP_FILE.dmp.Z. &

# *** Get the job number of the split background process   
   SPLIT_BGROUND_JOBNUM=$!
   echo " Proccss ID for FIle Split = $SPLIT_BGROUND_JOBNUM"

# *** Check the export Mode & Begin  export 
  if [ "$3" = 'full' ]
   then 
    exp system/$SYS_PWD@$HOST_STR file=$EXP_PIPE log=$EXP_FILE.log full=y compress=n direct=y consistent=y buffer=204857600 &
    exp_status=$?
  elif  [ "$3" = 'schema' ]
   then
    exp system/$SYS_PWD@$HOST_STR file=$EXP_PIPE log=$EXP_FILE.log parfile=$PARFILE   &
    exp_status=$?
  elif  [ "$3" = 'table' ]
   then
    exp system/$SYS_PWD@$HOST_STR file=$EXP_PIPE log=$EXP_FILE.log parfile=$PARFILE   &
    exp_status=$?
  fi

# ***  check export status  
  if [ $exp_status -ne 0 ]
              then
               echo " PROBLEM with the export, please check log file = $EXP_FILE.log "
               exit1
            fi

# *** Wait for the split background process to complete before proceeding
   wait $SPLIT_BGROUND_JOBNUM


# *** generate CREATE TBSP script
   echo " "
   echo "Generating TABLESPACE build script.......create_tablespace.lst."
#   $BKUP_SCR_DIR/generate_create_tbsp_scr.sh $EXP_DIR/create_tablespace.lst

# *** Create Import Restore Script 

IMP_FILE=$EXP_DIR/import_$3.sh
PAR_FILE=$EXP_DIR/import_parameter.txt

rm -f $IMP_FILE
cp $BKUP_SCR_DIR/import_parameter.txt $PAR_FILE 

echo "\n#.......RESTORE script for importing........  " > $IMP_FILE
echo "#For Full database import, may want to set following init.ora to stop logging all DDL,DML to REDO logs " >> $IMP_FILE
echo "#     init.ora parameter =  _disable_logging=true , remove it after import " >> $IMP_FILE
echo "\n#.......Removing old pipes prior to import  " >> $IMP_FILE
echo " rm -f $EXP_DIR/zip_pipe " >> $IMP_FILE
echo " rm -f $EXP_DIR/imp_pipe " >> $IMP_FILE
echo "\n#.......Creating new pipes prior to import  " >> $IMP_FILE
echo " mknod $EXP_DIR/zip_pipe p & " >> $IMP_FILE
echo " mknod $EXP_DIR/imp_pipe p & " >> $IMP_FILE
echo "\n#.......Joining all spilt files for import  " >> $IMP_FILE
echo " cat $EXP_FILE.dmp.Z.[a-z]* > $EXP_DIR/zip_pipe & " >> $IMP_FILE
echo "\n#.......uncompressing the joined file for import  " >> $IMP_FILE
echo " uncompress < $EXP_DIR/zip_pipe > $EXP_DIR/imp_pipe & " >> $IMP_FILE
echo "\n#.......Launching Import  " >> $IMP_FILE
echo "# imp  parfile=$PAR_FILE file=$EXP_DIR/imp_pipe " >> $IMP_FILE

echo " Finished creating Restore script for import of $3 of database "
echo " Import script= $IMP_FILE " 

BKUP_ENDTIME=`date +%m%d%y.%H:%M:%S`

echo " \n Start Time    : $BKUP_STARTTIME "
echo " Finished Time : $BKUP_ENDTIME "
