

#  File Name  :  exp_bkup.sh
#  Desciption :  Runs an Oracle Export given the following parameter/s:
#
#   Created by  :  Ajay Jain  01/15/03
#   Modified by :
###   use     _disable_logging=true  for import 

ERRMSG="`basename $0`: syntax error: exp_bkup.sh system_password host_string <backup dir>"

if [ "$1" ]; then SYS_PWD=$1; else echo "  System Password is missing"  >&2; exit 1; fi
if [ "$2" ]; then HOST_STR=$2; else echo " DataBase Name is Missing"  >&2; exit 1; fi
# Supply PARFILE name as full path name + File Name
if [ "$3" ]; then EXP_PARFILE=$3; else echo "Parameter file Name is missing " >&2; exit 1; fi
if [ "$4" ]; then EXP_DIR=$4; else EXP_DIR=/orabackup/$HOST_STR/exp; fi

BKUP_SCR_DIR=/orabackup/scripts
EXP_FILE=$EXP_DIR/$HOST_STR_`date +%m%d%y__%H:%M:%S`
#EXP_DIR=/orabackup/$HOST_STR/exp
#EXP_PARFILE=$BKUP_SCR_DIR/exp_parfile.txt
EXP_PIPE=$EXP_DIR/"$HOST_STR"_epipe
SPLIT_PIPE=$EXP_DIR/"$HOST_STR"_spipe
TEMP_DIR=$EXP_DIR
SPLIT_SIZE=500m

BKUP_STARTTIME=`date +%m%d%y.%H:%M:%S`

echo "Starting Export of $HOST_STR... :$BKUP_STARTTIME"

# *** Check if Backup Dir exists
   if [ ! -w $EXP_DIR ]
       then echo "\n   Missing Backup Dir = $EXP_DIR, Going to create it now... "
            mkdir $EXP_DIR
            status=$?
            if [ $status -ne 0 ]
              then
               echo " Can not create Backup Dir = $BKUP_DIR , aborting the backup task "
               exit1
              else echo " Backup dir =  $EXP_DIR, was missing, just created new one "
            fi
     else  echo "\n Backup Dir exists, Going ahead with backup process, all Data will be overwritten on this dir, if exists   "
   fi



# *** Check if instance is up before running export
   echo "\nChecking if instance is up..."
   INSTANCE_STATUS=`$BKUP_SCR_DIR/check_instance_up.sh $HOST_STR`
   if [ "$INSTANCE_STATUS" = "1" ]; then
      echo "BACKUP ERROR: Cannot perform Oracle Export on $HOST_STR, instance maybe down."
      echo "Status: 1"
   exit 1
   fi

# *** Check if SYSTEM password is valid
echo "\nChecking if SYSTEM password is valid..."
#   SYSTEMPASSWD_VALID=`$BKUP_SCR_DIR/check_system_passwd.sh $SYS_PWD $HOST_STR \
#                    $EXP_DIR/check_system_passwd.sh.log`
#   if [ "$SYSTEMPASSWD_VALID" = "1" ]; then
#      echo "BACKUP ERROR: Invalid SYSTEM password, cannot perform EXP backup."
#      echo "Status: $SYSTEMPASSWD_VALID"
#      exit 1
#   fi        

# *** Check if export pipe exists before deleting it 
   if [ -r $TEMP_DIR/$EXP_PIPE ]; then 
      rm $TEMP_DIR/$EXP_PIPE
   fi

# *** Delete all files in export directory which filename starts with HOST_STR 
   if [ -r $EXP_DIR/"$HOST_STR"*.log ]; then
      rm $EXP_DIR/"$HOST_STR"*.log
   fi

# *** Create a named pipes for export
   mknod $EXP_PIPE p
   mknod $SPLIT_PIPE p

# *** Compress the export pipe 
   compress < $EXP_PIPE > $SPLIT_PIPE &

# *** Split the compressed pipe into files of size not more than $SPLIT_SIZE
   split -b"$SPLIT_SIZE" $SPLIT_PIPE $EXP_FILE.dmp.Z. &

# *** Get the job number of the split background process   
   SPLIT_BGROUND_JOBNUM=$!

# *** Begin Export
   exp system/$SYS_PWD@$HOST_STR file=$EXP_PIPE log=$EXP_FILE.log parfile=$EXP_PARFILE &

### Test Export Script
#####exp system/manager buffer=204857600 compress=n direct=y consistent=n tables=inv.mtl_material_transactions log=t1.log &

# *** Wait for the split background process to complete before proceeding
   wait $SPLIT_BGROUND_JOBNUM


# *** Generate CREATE TBSP script
   echo " "
   echo "Generating TABLESPACE build script..."
   $BKUP_SCR_DIR/generate_create_tbsp_scr.sh \
              $SYS_PWD $HOST_STR $EXP_FILE.tbsp.sql



