#   File Name:  hot_bkup.sh
#
#   Purpose:  Runs several scripts to perform a hot backup and generate
#              a restore script. 
#
#   Assumption:
#                
#
#
# How to run:
# /orabackup/scripts/hot_bkup.sh system_password HOST_STR | tee logfile

ERRMSG="`basename $0`: syntax error "

if [ "$1" ]; then HOST_STR=$1;       else echo $ERRMSG >&2; exit 1; fi        
if [ "$2" ]; then BKUP_DIR=$2;       else echo $ERRMSG >&2; exit 1; fi            
if [ "$3" ];  then NUM_OF_PROCS=$3 ; else NUM_OF_PROCS=5   ; fi


BKUP_ARCHLOG_DIR=/orabackup/$HOST_STR/arch
BKUP_SCR=/orabackup/scripts
CTLFILE_LST=$BKUP_DIR/$HOST_STR.ctlfile.lst
REDOLOGS_LST=$BKUP_DIR/$HOST_STR.redo.lst
#ARCHLOG_LST=$BKUP_DIR/$HOST_STR.archlog.lst
TBSPACE_LST2=$BKUP_DIR/$HOST_STR.tbspace2.lst
GROUPFILE_LST=$BKUP_DIR/$HOST_STR.groupfile.lst
####BKUP_CTLFILE=$BKUP_DIR/$HOST_STR.`date +%m%d%y`.ctl
BKUP_CTLFILE=$BKUP_DIR/$HOST_STR.binary_backup_control_file.ctl
RESTORE_SCR=$BKUP_DIR/RESTORE_$HOST_STR.sh
FILE_COUNT_LST=$BKUP_DIR/$HOST_STR.filecount.lst
DETAILDFILE_LST=$BKUP_DIR/$HOST_STR.detailed_dfile_info.lst
DUPFILE_LST=$BKUP_DIR/$HOST_STR.dupfile.lst


BKUP_STARTTIME=`date +%m%d%y.%H:%M:%S`

echo "Starting hot backup of $HOST_STR... :$BKUP_STARTTIME"

# *** Check if instance is up, if not return error message
   echo "\nChecking if instance is up ..."
   INSTANCE_STATUS=`$BKUP_SCR/check_instance_up.sh $HOST_STR > $INST_STAT`
     if [ "$INSTANCE_STATUS" = "1" ]; then
        echo "     Instance is not up.  Quitting HOT BACKUP  of $HOST_STR...."
        echo "     Status: $INSTANCE_STATUS"
        exit 1
    else
        echo "     Status : Instanec is up, continueing   with HOT Backup .."
     fi

# *** Check if file_name ( without path name) is duplicate or not
# *** Genearte file for Duplicate
     echo   "\nCheck if file_name ( without path name) is duplicate or not"
     $BKUP_SCR/get_duplicate_file.sh  $DUPFILE_LST
     ls -l $DUPFILE_LST
# *** Begin Check for duplicate file names
     DUP_STATUS=`$BKUP_SCR/check_duplicate_file.sh  $DUPFILE_LST $HOST_STR $BKUP_DIR`
     if [ "$DUP_STATUS" = "1" ]; then
        echo "     Dupliate file is found, check $DUPFILE_LOG for details...."
        echo "     Status: $DUP_STATUS"
        exit 1
    else
        echo "     Status : NO Duplicate Files (dbf,ctl,log) found .."
     fi


# *** Check if instance is in ARCHIVE LOG mode & get ARCHIVE LOG Destination
   echo "\nChecking if instance is in ARCHIVE LOG mode ..."
   $BKUP_SCR/check_archivelog_mode.sh $BKUP_DIR/archive_check.log
   STATUS=$?
   ls-l $BKUP_DIR/archive_check.log

###$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
###$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$


# *** Check if any Tablespace is still in BackUP mode from last backup
   echo "\nCheck if any Tablespace is still in BackUP mode from last backup..."

# *** Check last checkpoint # archivelog switch  number 
   echo "\nCheck last checkpoint # archivelog switch  number ..."

###$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
###$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$

# *** Delete previous backups in backup directory
echo "\nRemoving Old Backup files from Hot Backup Directory ..."
rm -f $BKUP_DIR/*.Z \
      $BKUP_DIR/*.log \
      $BKUP_DIR/*.trc \
      $BKUP_DIR/"$HOST_STR"*.lst \
      $BKUP_DIR/"$HOST_STR"*.ctl \
      $BKUP_DIR/init"$HOST_STR".ora      

# *** Backup init.ora , spfile.ora  and Control File to trace
   echo '\nBacking up init.ora and control file to trace ...'
   CTL_TRACE_DIR=`$BKUP_SCR/bkup_ctl_totrc.sh`
   CTL_TRACE_FILE=`ls -1t $CTL_TRACE_DIR | head -1`
   cp -p $CTL_TRACE_DIR/$CTL_TRACE_FILE $BKUP_DIR/.
   if [ -r $ORACLE_HOME/dbs/init$HOST_STR.ora ]; then cp -p $ORACLE_HOME/dbs/init$HOST_STR.ora $BKUP_DIR/. ; fi
   if [ -r $ORACLE_HOME/dbs/spfile$HOST_STR.ora ]; then cp -p $ORACLE_HOME/dbs/spfile$HOST_STR.ora $BKUP_DIR/. ; fi
   if [ -r $ORACLE_HOME/dbs/orapw$HOST_STR ]; then cp -p $ORACLE_HOME/dbs/orapw$HOST_STR $BKUP_DIR/. ; fi

# *** Create file count for all files ( control, log, temp, data files) for info only
   echo "\nCreating File Count list ...$FILE_COUNT_LST"
   $BKUP_SCR/get_file_count.sh  $FILE_COUNT_LST
   echo "     Status: $?"
   ls -l $FILE_COUNT_LST

# *** Create instance Restore script
   echo "\nCreating instance Restore script ... $RESTORE_SCR"
   $BKUP_SCR/hot_backup_restore.sh  $HOST_STR  $BKUP_DIR
   echo "Status: $?"
   ls -l $RESTORE_SCR

# *** Alter system checkpoint and create current copy of Archive LOG BEFORE taking hot backup 
   echo "\n Performing  system checkpint and create current copy of Archive LOG BEFORE taking hot backup ..."
   $BKUP_SCR/hot_pre_backup_checkpoint.sh $BKUP_DIR/arch_pre_backup.lst 
   echo " Finished CHECKPOINT  and ARCHIVE LOG CURRENT of the database"


# *** create table with number of processes, tablespace_name, bytes
     $BKUP_SCR/hot_tbs_sort.sh $NUM_OF_PROCS

# *** Generate tablespace list for each parallel processes
      $BKUP_SCR/hot_get_tablespace_group_list.sh $BKUP_DIR 

# *** Generating List of datafiles for each tablespace  for Hot Backup
   echo "\n Generating Complete List of Datafiles with tablespace    ...$TBSPACE_LST2"
   $BKUP_SCR/hot_get_dfile_per_tbsp.sh $TBSPACE_LST2 

echo '\nHot Backup in  Parallel= $NUM_OF_PROCS  Starting  at this time...`date +%m_%d_%y.%H:%M:%S`'

   $BKUP_SCR/hot_backup_process.sh $BKUP_DIR/tbs_group1.lst $TBSPACE_LST2 1 $BKUP_DIR $BKUP_SCR > $BKUP_DIR/hot_group1.log &
   JOB1=$!
   echo "Job #1 Proc ID : " $JOB1

   $BKUP_SCR/hot_backup_process.sh $BKUP_DIR/tbs_group2.lst $TBSPACE_LST2 2 $BKUP_DIR $BKUP_SCR > $BKUP_DIR/hot_group2.log &
   JOB2=$!
   echo "Job #2 Proc ID : " $JOB2

   $BKUP_SCR/hot_backup_process.sh $BKUP_DIR/tbs_group3.lst  $TBSPACE_LST2 3 $BKUP_DIR $BKUP_SCR > $BKUP_DIR/hot_group3.log &
   JOB3=$!
   echo "Job #3 Proc ID : " $JOB3

   $BKUP_SCR/hot_backup_process.sh $BKUP_DIR/tbs_group4.lst $TBSPACE_LST2 4 $BKUP_DIR $BKUP_SCR > $BKUP_DIR/hot_group4.log &
   JOB4=$!
   echo "Job #4 Proc ID : " $JOB4
   
   $BKUP_SCR/hot_backup_process.sh $BKUP_DIR/tbs_group5.lst $TBSPACE_LST2 5 $BKUP_DIR  $BKUP_SCR > $BKUP_DIR/hot_group5.log &
   JOB5=$!
   echo "Job #5 Proc ID : " $JOB5

   $BKUP_SCR/hot_backup_process.sh $BKUP_DIR/tbs_group6.lst $TBSPACE_LST2 6 $BKUP_DIR $BKUP_SCR > $BKUP_DIR/hot_group6.log &
   JOB6=$!
   echo "Job #6 Proc ID : " $JOB6

   $BKUP_SCR/hot_backup_process.sh $BKUP_DIR/tbs_group7.lst $TBSPACE_LST2 7 $BKUP_DIR $BKUP_SCR > $BKUP_DIR/hot_group7.log &
   JOB7=$!
   echo "Job #7 Proc ID : " $JOB7

   $BKUP_SCR/hot_backup_process.sh $BKUP_DIR/tbs_group8.lst $TBSPACE_LST2 8 $BKUP_DIR $BKUP_SCR > $BKUP_DIR/hot_group8.log &
   JOB8=$!
   echo "Job #8 Proc ID : " $JOB8

   $BKUP_SCR/hot_backup_process.sh $BKUP_DIR/tbs_group9.lst $TBSPACE_LST2 9 $BKUP_DIR $BKUP_SCR > $BKUP_DIR/hot_group9.log &
   JOB9=$!
   echo "Job #9 Proc ID : " $JOB9

   wait $JOB1
   wait $JOB2
   wait $JOB3
   wait $JOB4
   wait $JOB5
   wait $JOB6
   wait $JOB7
   wait $JOB8
   wait $JOB9
   
   echo "\n***Tablespace backup & DataFiles Compression Status from Process#1 : "
   cat $BKUP_DIR/hot_group1.log
   echo "\n***Tablespace backup & DataFiles Compression Status from Process#2 : "
   cat $BKUP_DIR/hot_group2.log
   echo "\n***Tablespace backup & DataFiles Compression Status from Process#3 : "
   cat $BKUP_DIR/hot_group3.log
   echo "\n***Tablespace backup & DataFiles Compression Status from Process#4 : "
   cat $BKUP_DIR/hot_group4.log
   echo "\n***Tablespace backup & DataFiles Compression Status from Process#5 : "
   cat $BKUP_DIR/hot_group5.log
   echo "\n***Tablespace backup & DataFiles Compression Status from Process#6 : "
   cat $BKUP_DIR/hot_group6.log
   echo "\n***Tablespace backup & DataFiles Compression Status from Process#7 : "
   cat $BKUP_DIR/hot_group7.log
   echo "\n***Tablespace backup & DataFiles Compression Status from Process#8 : " 
   cat $BKUP_DIR/hot_group8.log
   echo "\n***Tablespace backup & DataFiles Compression Status from Process#9 : "
   cat $BKUP_DIR/hot_group9.log



echo '\nHot Backup of tablespace  Finished at this time...`date +%m_%d_%y.%H:%M:%S`'


# *** OS copy of binary control files
 echo "\nChecking for the List of control files ... $CTLFILE_LST"
   if [ -r $CTLFILE_LST ]
     then
        echo "     Control File list $CTLFILE_LST  EXISTS & was created by Restore Script"
     else
        echo "     Getting list of control files ... $CTLFILE_LST"
        $BKUP_SCR/get_ctlfiles.sh  $CTLFILE_LST
    fi
   echo "\n Copying the binary control files ..."
   $BKUP_SCR/bkup_compress.sh $CTLFILE_LST $BKUP_DIR | tee $CTLFILE_LST.log
   echo "     Status: $?"


# *** Backup redo logs
    if [ -r $REDOLOGS_LST ]
     then
        echo "     REDO LOG File list $REDOLOGS_LST  EXISTS & was created by Restore Script"
     else
        echo "     Getting list of REDO LOG files ... $REDOLOGS_LST"
        $BKUP_SCR/get_redologs.sh  $REDOLOGS_LST
    fi
   echo "\n Copying the Redolog & Standby Logs  files ..."
   $BKUP_SCR/bkup_compress.sh $REDOLOGS_LST $BKUP_DIR | tee $REDOLOGS_LST.log
   echo "     Status: $?"

# *** Get a binary backup of control file and archive log current after backup
# *** Get SCN # after archive log switch
  echo '\nCreating Binary Backup Cntrol File just prior to  archive log current...'
  $BKUP_SCR/hot_post_backup_checkpoint.sh $BKUP_CTLFILE $BKUP_DIR/arch_post_backup.lst


# *** Compress & remove all current archive log files to $BKUP_DIR
#echo "\nCompressing & removing archive log files to $BKUP_ARCHLOG_DIR ..."   
#$BKUP_SCR/compress_remove_archlogs.sh  $HOST_STR $BKUP_ARCHLOG_DIR



###$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
# *** Check if any Tablespace is still in BackUP mode from last backup
   echo "\nChecking if instance is in ARCHIVE LOG mode ..."

###$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$

  
# *** Report Backup Start/End Time
echo "\n\nHot Backup of $HOST_STR ended."
echo "Start time:  $BKUP_STARTTIME"
echo "End   time:  `date +%m%d%y.%H:%M:%S`"  
