#   File Name: remove_aged_files.sh 
#
#   Purpose: To remove $2 files in $1 directory which 
#            have not been modified in $3 days
#
#   Parameters:   
#        $1  DIR TO CLEAN
#        $2  File Name (can use wildcards)
#        $3  Age of files to remove (in days)
#
#   WARNING: This will remove the files without interactive verification.
#            Please be careful in using this script.
#
#   Created by  :  Ajay Jain  01/15/03
#   Modified by :
#
#

ERRMSG="`basename $0`: syntax error: `basename $0` <dir> <file pattern> <age in days>"

if [ "$1" ]
then DIR_TO_CLEAN=$1
else echo $ERRMSG >&2
  exit 1
fi

if [ "$2" ]
then FILE_TO_RM=$2
else echo $ERRMSG >&2
  exit 1
fi

if [ "$3" ]
then FILE_AGE_TO_RM=$3
else echo $ERRMSG >&2
  exit 1
fi

echo "\nAbout to remove the following" \
     `find $DIR_TO_CLEAN -name "$FILE_TO_RM" -mtime +$FILE_AGE_TO_RM -exec ls -l {} \; | wc -l` \
     "file/s (files older than $FILE_AGE_TO_RM day/s) in $DIR_TO_CLEAN ...\n"
find $DIR_TO_CLEAN -name "$FILE_TO_RM" -mtime +$FILE_AGE_TO_RM -exec ls -l {} \; 
echo "\nRemoving the above listed files ..."
find $DIR_TO_CLEAN -name "$FILE_TO_RM" -mtime +$FILE_AGE_TO_RM -exec rm {} \; 
echo "Status: " $?

